Peripherals

Struct Peripherals 

pub struct Peripherals {
Show 29 fields pub SRAM: Sram, pub BUS: Bus, pub DTC: Dtc, pub ICU: Icu, pub DBG: Dbg, pub SYSC: Sysc, pub ELC: Elc, pub IWDT: Iwdt, pub MSTP: Mstp, pub CRC: Crc, pub PORT0: Port0, pub PORT1: Port1, pub PORT2: Port2, pub PORT3: Port3, pub PORT4: Port4, pub PORT9: Port9, pub PFS_A: PfsA, pub PORGA: Porga, pub ADC_D: AdcD, pub SAU0: Sau0, pub SAU1: Sau1, pub TAU: Tau, pub RTC_C: RtcC, pub IICA: Iica, pub UARTA: Uarta, pub TML32: Tml32, pub PCLBUZ: Pclbuz, pub TRNG: Trng, pub FLCN: Flcn,
}
Required for compatibility with RTIC and other frameworks

Fields

SRAM: SramBUS: BusDTC: DtcICU: IcuDBG: DbgSYSC: SyscELC: ElcIWDT: IwdtMSTP: MstpCRC: CrcPORT0: Port0PORT1: Port1PORT2: Port2PORT3: Port3PORT4: Port4PORT9: Port9PFS_A: PfsAPORGA: PorgaADC_D: AdcDSAU0: Sau0SAU1: Sau1TAU: TauRTC_C: RtcCIICA: IicaUARTA: UartaTML32: Tml32PCLBUZ: PclbuzTRNG: TrngFLCN: Flcn

Implementations

Source

impl Peripherals

pub fn take() -> Option<Self>

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks

pub fn steal() -> Self

Returns Peripheral struct multiple times Required for compatibility with RTIC and other frameworks